@@ -4,7 +4,7 @@ Module Docstring
 """
 
 __author__ = "Lorenz Leitner"
-__version__ = "1.4.0"
+__version__ = "1.5.0"
 __license__ = "GPL-3.0"
 
 # Libraries
@@ -80,12 +80,7 @@ def set_color(color):
         sys.stdout.write(str(g) + " ")
         sys.stdout.write(str(b) + "\n")
 
-    rgb = []
-    rgb.append(r)
-    rgb.append(g)
-    rgb.append(b)
-
-    return rgb
+    return [r, g, b]
 
 
 def get_effects_of_device(device):
@@ -120,7 +115,7 @@ def list_devices(device_manager):
 
         if (args.list_devices_long):
             print("   capabilities: {}".format(device.capabilities))
-        if (args.list_devices_long_human):
+        elif (args.list_devices_long_human):
             print("   capabilities:")
             for i in device.capabilities:
                 print("      ", i, "=", device.capabilities[i])
@@ -376,6 +371,11 @@ def read_args():
                         dest='brightness',
                         action="store")
 
+    parser.add_argument("--sync",
+                        help="sync lighting effects to all supported "
+                        "Razer products",
+                        action="store_true")
+
     global args
     args = parser.parse_args()
 
@@ -383,9 +383,6 @@ def read_args():
         parser.print_help()
         sys.exit(1)
 
-    if args.verbose:
-        print("Starting Razer colors script...")
-
 
 def main():
     """ Main entry point of the app """
@@ -397,15 +394,10 @@ def main():
     # Create a DeviceManager. This is used to get specific devices
     device_manager = DeviceManager()
 
-    if (args.list_devices or args.list_devices_long or
-            args.list_devices_long_human):
-        list_devices(device_manager)
-
     # Disable daemon effect syncing.
     # Without this, the daemon will try to set the lighting effect to every
     # device.
-    # TODO: Could be enabled as flag
-    device_manager.sync_effects = False
+    device_manager.sync_effects = args.sync
 
     # Do below only if dry run is not specified
     if args.automatic or args.effect or args.color:
@@ -428,6 +420,10 @@ def main():
     if args.brightness:
         set_brightness(device_manager)
 
+    if (args.list_devices or args.list_devices_long or
+            args.list_devices_long_human):
+        list_devices(device_manager)
+
 
 if __name__ == "__main__":
     """ This is executed when run from the command line - obsolete """
